==> spip_3.2.11.orig.tar.xz: plugins-dist/revisions/lang/revisions_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'Все изменения',

	// D
	'diff_para_ajoute' => 'Абзац добавили',
	'diff_para_deplace' => 'Абзац переместили',
	'diff_para_supprime' => 'Абзац удалили',
	'diff_texte_ajoute' => 'Текст добавили',
	'diff_texte_deplace' => 'Текст переместили',
	'diff_texte_supprime' => 'Текст удалили',
	'differences_versions' => 'Отличия между версией №@id_version@ и №@id_diff@',

	// I
	'icone_restaurer_version' => 'Восстановить версию №@version@',
	'icone_suivi_revisions' => 'Отслеживание изменений',
	'info_1_revision' => '1 версия',
	'info_aucune_revision' => 'У этого материала нет других версий',
	'info_historique' => 'Изменения в ',
	'info_historique_lien' => 'История изменений',
	'info_historique_titre' => 'История изменений',
	'info_nb_revisions' => 'Изменения в материалах (@nb@)',

	// L
	'label_choisir_id_version' => 'Сравнить с предыдущей версией',
	'label_config_revisions_objets' => 'Сохранять историю изменений для:',

	// M
	'message_valider_recuperer_version' => 'Заполните форму для того, чтобы восстановится до этой версии.',

	// O
	'objet_editorial' => 'объект',

	// P
	'plugin_update' => 'Обновить плагин "Révisions" до версии @version@.',

	// T
	'titre_form_revisions_objets' => 'Вести историю изменений',
	'titre_restaurer_version' => 'Вернуться к варианту',
	'titre_revisions' => 'История изменений',

	// V
	'version_deplace_rubrique' => 'Переместить <b>« @from@ »</b> в <b>« @to@ »</b>.',
	'version_initiale' => 'Начальная версия',
	'voir_differences' => 'Посмотреть отличия',
	'voir_mes_revisions' => 'Мои изменения',
	'voir_revisions' => 'История изменений (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Все изменения'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=ru
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'Все изменения',

	// D
	'diff_para_ajoute' => 'Абзац добавили',
	'diff_para_deplace' => 'Абзац переместили',
	'diff_para_supprime' => 'Абзац удалили',
	'diff_texte_ajoute' => 'Текст добавили',
	'diff_texte_deplace' => 'Текст переместили',
	'diff_texte_supprime' => 'Текст удалили',
	'differences_versions' => 'Отличия между версией №@id_version@ и №@id_diff@',

	// I
	'icone_restaurer_version' => 'Восстановить версию №@version@',
	'icone_suivi_revisions' => 'Отслеживание изменений',
	'info_1_revision' => '1 версия',
	'info_aucune_revision' => 'У этого материала нет других версий',
	'info_historique' => 'Изменения в ',
	'info_historique_lien' => 'История изменений',
	'info_historique_titre' => 'История изменений',
	'info_nb_revisions' => 'Изменения в материалах (@nb@)',

	// L
	'label_choisir_id_version' => 'Сравнить с предыдущей версией',
	'label_config_revisions_objets' => 'Сохранять историю изменений для:',

	// M
	'message_valider_recuperer_version' => 'Заполните форму для того, чтобы восстановится до этой версии.',

	// O
	'objet_editorial' => 'объект',

	// P
	'plugin_update' => 'Обновить плагин "Révisions" до версии @version@.',

	// T
	'titre_form_revisions_objets' => 'Вести историю изменений',
	'titre_restaurer_version' => 'Вернуться к варианту',
	'titre_revisions' => 'История изменений',

	// V
	'version_deplace_rubrique' => 'Переместить <b>« @from@ »</b> в <b>« @to@ »</b>.',
	'version_initiale' => 'Начальная версия',
	'voir_differences' => 'Посмотреть отличия',
	'voir_mes_revisions' => 'Мои изменения',
	'voir_revisions' => 'История изменений (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Все изменения',
];
